#ifndef NT2_INCLUDE_FUNCTIONS_LU_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LU_HPP_INCLUDED

#include <nt2/linalg/include/functions/lu.hpp>

#endif
